import { lookupCambridge, capitalize } from './helper.js';

// Render History 

const renderHistory = (arr) => {
  const historyHTML = arr.map((item) => `<li data-value=${item}><span>${item}</span><i title="Remove this" class="btn-remove">&times;</i></li>`).join("");
  document.querySelector("#lookup-history ol").innerHTML = historyHTML;
};

const removeHistoryItem = (arr) => {
  document.querySelectorAll("#lookup-history li").forEach((item, index) => {
    item.addEventListener("click", function (e) {
      if (e.target.nodeName === "SPAN") {
        chrome.storage.local.get(["dictionary"], function (result) {
          lookupCambridge(item.dataset.value, result.dictionary);
        });
      }

      if (e.target.classList.contains("btn-remove")) {
        arr.splice(index, 1);
        chrome.storage.local.set(
          {
            "cambridge-history": arr,
          },
          () => {
            console.log(index);
          }
        );
      }
    });
  });
}

const btnExchangeHTML = `<i title="Change language direction" class="btn-exchange">⇆</i>`;
document.querySelectorAll('#dictionary-selector li').forEach((item) => {
  const value = item.dataset.value;
  item.innerText = value;
  if (item.closest('.bilingual-dictionary')) {
    item.insertAdjacentHTML('beforeend', btnExchangeHTML);
  }

  chrome.storage.local.get(['dictionary'], function (result) {
    value === result.dictionary && (item.classList.add('active'));
  });

  item.addEventListener('click', function (e) {
    if (e.target.classList.contains("btn-exchange")) {
      this.dataset.value = this.dataset.value.split("-").reverse().join("-");
      this.childNodes[0].nodeValue = capitalize(this.dataset.value);
      return;
    }

    document.querySelector('#dictionary-selector li.active') !== null && document.querySelector('#dictionary-selector li.active').classList.remove('active');
    document.querySelector('.current-dictionary span').innerText = this.dataset.value;
    this.classList.add('active');
    chrome.storage.local.set({ dictionary: this.dataset.value }, () => {
      console.log('dictionary is set to ' + this.dataset.value);
    });
    document.querySelector('.dictionary-checkbox').checked = false;
  });
});

chrome.storage.local.get(['dictionary'], function (result) {
  document.querySelector('#form-input').setAttribute('placeholder', `Search ${capitalize(result.dictionary)}`);
  document.querySelector('.current-dictionary span').innerText = result.dictionary;
  document.querySelector('#form-input').focus();
});

chrome.storage.onChanged.addListener(function(changes, namespace) {
  if ("dictionary" in changes) {
    document.querySelector('#form-input').setAttribute('placeholder', `Search ${capitalize(changes.dictionary.newValue)}`);
    document.querySelector('#form-input').focus();
  }

  if ("cambridge-history" in changes) {
    const { newValue } = changes["cambridge-history"];
    renderHistory(newValue);
    removeHistoryItem(newValue);
  }
});

chrome.storage.local.get(["cambridge-history"], function (result) {
  const list = result["cambridge-history"];
  renderHistory(list);
  removeHistoryItem(list);
});

document.querySelector('#form').addEventListener('submit', function (e) {
  e.preventDefault();
  const input = document.querySelector('#form-input').value;
  chrome.storage.local.get(['dictionary'], function(result) {
      lookupCambridge(input, result.dictionary);
      document.querySelector('#form-input').value = '';
  });

  chrome.storage.local.get(["cambridge-history"], function (result) {
    const list = result["cambridge-history"];
    if (list.includes(input)) return;
    chrome.storage.local.set(
      {
        "cambridge-history": list.length < 20 ? [input, ...list] : (list.pop(), [input, ...list]),
      },
      () => {
        console.log(list);
      }
    );
  });
});
